@@ -48,7 +48,9 @@
 #include "vlandevice.h"
 #include "wireddevice.h"
 #include "wirelessdevice.h"
+#if !NM_CHECK_VERSION(1, 2, 0)
 #include "wimaxdevice.h"
+#endif
 
 #include "nmdebug.h"
 
@@ -78,8 +80,10 @@ NetworkManager::NetworkManagerPrivate::NetworkManagerPrivate()
     , nmState(NetworkManager::Unknown)
     , m_connectivity(NetworkManager::UnknownConnectivity)
     , m_isNetworkingEnabled(false)
+#if !NM_CHECK_VERSION(1, 2, 0)
     , m_isWimaxEnabled(false)
     , m_isWimaxHardwareEnabled(false)
+#endif
     , m_isWirelessEnabled(false)
     , m_isWirelessHardwareEnabled(false)
     , m_isWwanEnabled(false)
@@ -130,6 +134,7 @@ void NetworkManager::NetworkManagerPrivate::init()
     qDBusRegisterMetaType<QList<QDBusObjectPath> >();
     qDBusRegisterMetaType<DeviceDBusStateReason>();
     qDBusRegisterMetaType<NMVariantMapMap>();
+    qDBusRegisterMetaType<NMVariantMapList>();
     qDBusRegisterMetaType<NMStringMap>();
 
     m_version = iface.version();
@@ -278,9 +283,11 @@ NetworkManager::Device::Ptr NetworkManager::NetworkManagerPrivate::createNetwork
     case Device::Bluetooth:
         createdInterface = Device::Ptr(new NetworkManager::BluetoothDevice(uni), &QObject::deleteLater);
         break;
+#if !NM_CHECK_VERSION(1, 2, 0)
     case Device::Wimax:
         createdInterface = Device::Ptr(new NetworkManager::WimaxDevice(uni), &QObject::deleteLater);
         break;
+#endif
     case Device::OlpcMesh:
         createdInterface = Device::Ptr(new NetworkManager::OlpcMeshDevice(uni), &QObject::deleteLater);
         break;
@@ -375,6 +382,7 @@ bool NetworkManager::NetworkManagerPrivate::isWwanHardwareEnabled() const
     return m_isWwanHardwareEnabled;
 }
 
+#if !NM_CHECK_VERSION(1, 2, 0)
 bool NetworkManager::NetworkManagerPrivate::isWimaxEnabled() const
 {
     return m_isWimaxEnabled;
@@ -384,6 +392,7 @@ bool NetworkManager::NetworkManagerPrivate::isWimaxHardwareEnabled() const
 {
     return m_isWimaxHardwareEnabled;
 }
+#endif
 
 QDBusPendingReply<QDBusObjectPath> NetworkManager::NetworkManagerPrivate::activateConnection(const QString &connectionUni, const QString &interfaceUni, const QString &connectionParameter)
 {
@@ -433,10 +442,12 @@ void NetworkManager::NetworkManagerPrivate::setWwanEnabled(bool enabled)
     iface.setWwanEnabled(enabled);
 }
 
+#if !NM_CHECK_VERSION(1, 2, 0)
 void NetworkManager::NetworkManagerPrivate::setWimaxEnabled(bool enabled)
 {
     iface.setWimaxEnabled(enabled);
 }
+#endif
 
 void NetworkManager::NetworkManagerPrivate::sleep(bool sleep)
 {
@@ -460,14 +471,26 @@ void NetworkManager::NetworkManagerPrivate::setLogging(NetworkManager::LogLevel
     case NetworkManager::Debug:
         logLevel = QLatin1String("DEBUG");
         break;
+#if NM_CHECK_VERSION(0, 9, 10)
+    case NetworkManager::Trace:
+        logLevel = QLatin1String("TRACE");
+        break;
+#endif
     }
     if (!domains.testFlag(NoChange)) {
         if (domains.testFlag(NetworkManager::None)) {
             logDomains << QLatin1String("NONE");
         }
+#if NM_CHECK_VERSION(0, 9, 10)
+        if (domains.testFlag(NetworkManager::Hardware)) {
+            logDomains << QLatin1String("PLATFORM");
+        }
+#else
         if (domains.testFlag(NetworkManager::Hardware)) {
             logDomains << QLatin1String("HW");
         }
+#endif
+
         if (domains.testFlag(NetworkManager::RFKill)) {
             logDomains << QLatin1String("RFKILL");
         }
@@ -552,6 +575,29 @@ void NetworkManager::NetworkManagerPrivate::setLogging(NetworkManager::LogLevel
         if (domains.testFlag(NetworkManager::Vlan)) {
             logDomains << QLatin1String("VLAN");
         }
+#if NM_CHECK_VERSION(0, 9, 10)
+        if (domains.testFlag(NetworkManager::Agents)) {
+            logDomains << QLatin1String("AGENTS");
+        }
+        if (domains.testFlag(NetworkManager::Settings)) {
+            logDomains << QLatin1String("SETTINGS");
+        }
+        if (domains.testFlag(NetworkManager::DbusProps)) {
+            logDomains << QLatin1String("DBUS_PROPS");
+        }
+        if (domains.testFlag(NetworkManager::Team)) {
+            logDomains << QLatin1String("TEAM");
+        }
+        if (domains.testFlag(NetworkManager::ConCheck)) {
+            logDomains << QLatin1String("CONCHECK");
+        }
+        if (domains.testFlag(NetworkManager::Dcb)) {
+            logDomains << QLatin1String("DCB");
+        }
+        if (domains.testFlag(NetworkManager::Dispatch)) {
+            logDomains << QLatin1String("DISPATCH");
+        }
+#endif
     }
     iface.SetLogging(logLevel, logDomains.join(QLatin1String(",")));
 }
@@ -573,14 +619,21 @@ QDBusPendingReply<uint> NetworkManager::NetworkManagerPrivate::checkConnectivity
 
 NetworkManager::ActiveConnection::Ptr NetworkManager::NetworkManagerPrivate::primaryConnection()
 {
-    return findRegisteredActiveConnection(iface.primaryConnection().path());
+    return findRegisteredActiveConnection(m_primaryConnection);
 }
 
 NetworkManager::ActiveConnection::Ptr NetworkManager::NetworkManagerPrivate::activatingConnection()
 {
-    return findRegisteredActiveConnection(iface.activatingConnection().path());
+    return findRegisteredActiveConnection(m_activatingConnection);
 }
 
+#if NM_CHECK_VERSION(1, 0, 0)
+NetworkManager::ConnectionSettings::ConnectionType NetworkManager::NetworkManagerPrivate::primaryConnectionType()
+{
+    return m_primaryConnectionType;
+}
+#endif
+
 #if NM_CHECK_VERSION(0, 9, 10)
 bool NetworkManager::NetworkManagerPrivate::isStartingUp() const
 {
@@ -588,6 +641,13 @@ bool NetworkManager::NetworkManagerPrivate::isStartingUp() const
 }
 #endif
 
+#if NM_CHECK_VERSION(1, 0, 6)
+NetworkManager::Device::MeteredStatus NetworkManager::NetworkManagerPrivate::metered() const
+{
+    return m_metered;
+}
+#endif
+
 void NetworkManager::NetworkManagerPrivate::onDeviceAdded(const QDBusObjectPath &objpath)
 {
     // qCDebug(NMQT);
@@ -675,6 +735,7 @@ void NetworkManager::NetworkManagerPrivate::propertiesChanged(const QVariantMap
             m_isWwanEnabled = it->toBool();
             qCDebug(NMQT) << property << m_isWwanEnabled;
             Q_EMIT wwanEnabledChanged(m_isWwanEnabled);
+#if !NM_CHECK_VERSION(1, 2, 0)
         } else if (property == QLatin1String("WimaxHardwareEnabled")) {
             m_isWimaxHardwareEnabled = it->toBool();
             qCDebug(NMQT) << property << m_isWimaxHardwareEnabled;
@@ -683,6 +744,7 @@ void NetworkManager::NetworkManagerPrivate::propertiesChanged(const QVariantMap
             m_isWimaxEnabled = it->toBool();
             qCDebug(NMQT) << property << m_isWimaxEnabled;
             Q_EMIT wimaxEnabledChanged(m_isWimaxEnabled);
+#endif
         } else if (property == QLatin1String("Version")) {
             m_version = it->toString();
             parseVersion(m_version);
@@ -691,12 +753,24 @@ void NetworkManager::NetworkManagerPrivate::propertiesChanged(const QVariantMap
         } else if (property == QLatin1String("Connectivity")) {
             connectivityChanged(it->toUInt());
         } else if (property == QLatin1String("PrimaryConnection")) {
-            Q_EMIT primaryConnectionChanged(it->value<QDBusObjectPath>().path());
+            m_primaryConnection = it->value<QDBusObjectPath>().path();
+            Q_EMIT primaryConnectionChanged(m_primaryConnection);
         } else if (property == QLatin1String("ActivatingConnection")) {
-            Q_EMIT activatingConnectionChanged(it->value<QDBusObjectPath>().path());
+            m_activatingConnection = it->value<QDBusObjectPath>().path();
+            Q_EMIT activatingConnectionChanged(m_activatingConnection);
+#if NM_CHECK_VERSION(1, 0, 0)
+        } else if (property == QLatin1String("PrimaryConnectionType")) {
+            m_primaryConnectionType = NetworkManager::ConnectionSettings::typeFromString(it->toString());
+            Q_EMIT primaryConnectionTypeChanged(m_primaryConnectionType);
+#endif
 #if NM_CHECK_VERSION(0, 9, 10)
         } else if (property == QLatin1String("Startup")) {
             Q_EMIT isStartingUpChanged();
+#endif
+#if NM_CHECK_VERSION(1, 0, 6)
+        } else if (property == QLatin1String("Metered")) {
+            m_metered = (NetworkManager::Device::MeteredStatus)it->toUInt();
+            Q_EMIT meteredChanged(m_metered);
 #endif
         } else {
             qCWarning(NMQT) << Q_FUNC_INFO << "Unhandled property" << property;
@@ -923,6 +997,7 @@ void NetworkManager::setWwanEnabled(bool enabled)
     globalNetworkManager->setWwanEnabled(enabled);
 }
 
+#if !NM_CHECK_VERSION(1, 2, 0)
 bool NetworkManager::isWimaxEnabled()
 {
     return globalNetworkManager->isWimaxEnabled();
@@ -937,6 +1012,7 @@ void NetworkManager::setWimaxEnabled(bool enabled)
 {
     globalNetworkManager->setWimaxEnabled(enabled);
 }
+#endif
 
 void NetworkManager::sleep(bool sleep)
 {
@@ -959,7 +1035,9 @@ NetworkManager::Device::Types NetworkManager::supportedInterfaceTypes()
                NetworkManager::Device::Ethernet |
                NetworkManager::Device::Wifi |
                NetworkManager::Device::Modem |
+#if !NM_CHECK_VERSION(1, 2, 0)
                NetworkManager::Device::Wimax |
+#endif
                NetworkManager::Device::Bluetooth |
                NetworkManager::Device::OlpcMesh |
                NetworkManager::Device::InfiniBand |
@@ -995,6 +1073,13 @@ NetworkManager::ActiveConnection::Ptr NetworkManager::activatingConnection()
     return globalNetworkManager->activatingConnection();
 }
 
+#if NM_CHECK_VERSION(1, 0, 0)
+NetworkManager::ConnectionSettings::ConnectionType NetworkManager::primaryConnectionType()
+{
+    return globalNetworkManager->primaryConnectionType();
+}
+#endif
+
 #if NM_CHECK_VERSION(0, 9, 10)
 bool NetworkManager::isStartingUp()
 {
@@ -1002,6 +1087,13 @@ bool NetworkManager::isStartingUp()
 }
 #endif
 
+#if NM_CHECK_VERSION(1, 0, 6)
+NetworkManager::Device::MeteredStatus NetworkManager::metered()
+{
+    return globalNetworkManager->metered();
+}
+#endif
+
 NetworkManager::Notifier *NetworkManager::notifier()
 {
     return globalNetworkManager;
